@@ -1647,7 +1647,7 @@ def test_conf_pipeline(conf, context):
     config.load_customer(conf['conf']) # Pass path
 
     # Prepare the sys path
-    found = []
+    available = []
 
     packages = conf['paths']['packages']
     for pkg in packages:
@@ -1665,7 +1665,7 @@ def test_conf_pipeline(conf, context):
                 print(redbg("Invalid transform: {} ({})".format(str(e), fullpath)))
                 continue
             print(greenbg("Loaded transform: {} => {}".format(tname, t.name)))
-            found.append(t.name)
+            available.append(t)
 
     libraries = conf['paths']['libraries']
     contribpath = os.path.join(os.path.dirname(__file__),
@@ -1693,15 +1693,35 @@ def test_conf_pipeline(conf, context):
                 print(redbg("Invalid transform: {} ({})".format(str(e), fullpath)))
                 continue
             print(greenbg("Loaded transform: {} => {}".format(tname, t.name)))
-            found.append(t.name)
+            available.append(t)
 
     print("\n\nLooking for required Transforms:")
-    for t in conf['transforms']['enabled']:
-        name = t['transform']
-        if name not in found:
+    for reqt in conf['transforms']['enabled']:
+        name = reqt['transform']
+        args = reqt['args']
+
+        status = 'missing'
+        for avt in available:
+            if avt.name == name:
+                print(greenbg("Found {}".format(name)))
+                status = 'notconfigured'
+
+            if status == 'missing':
+                continue
+
+            try:
+                avt.preload_clean_args(args)
+                status = 'configured'
+            except Exception as e:
+                print(redbg("Could not configure {}".format(name)))
+                traceback.print_exc()
+                break
+
+            print(greenbg("Configured {}".format(name)))
+            break
+
+        if status == 'missing':
             print(redbg("Could not find {}".format(name)))
-        else:
-            print(greenbg("Found {}".format(name)))
 
 def test_task_pipeline(conf, context):
     """
