@@ -99,8 +99,8 @@ def _start(commands):
             "cmd": [
                 '# file to be sourced before you start working. use the appropriate',
                 '# environment activation mechanism',
-                'echo "#source {}/bin/activate" >$ENRICH_ROOT/env.sh'.format(venv_root),
-                'echo "workon {}" >$ENRICH_ROOT/env.sh'.format(venv_name),
+                'echo "#source {}/bin/activate" > $ENRICH_ROOT/env.sh'.format(venv_root),
+                'echo "workon {}" >> $ENRICH_ROOT/env.sh'.format(venv_name),
                 'echo "export ENRICH_ROOT={}" >> $ENRICH_ROOT/env.sh'.format(enrich_root)
             ]
         },
@@ -142,11 +142,11 @@ def _start(commands):
             "description": "Bootstrap a transform",
             "cmd": [
                 "# Will create a python script",
-                "enrichpkg bootstrap -c transform-simple -p transforms/persona.py",
+                "enrichpkg bootstrap -c transform-simple -p transforms/helloworld.py",
                 "# Will create a python module",
-                "enrichpkg bootstrap -c transform-simple -p transforms/persona",
+                "enrichpkg bootstrap -c transform-simple -p transforms/helloworld",
                 "# Will create a python package",
-                "enrichpkg bootstrap -c transform-package -p transforms/persona",
+                "enrichpkg bootstrap -c transform-package -p transforms/helloworld",
                 "# Will create a hello world script",
                 "enrichpkg bootstrap -c transform-helloworld -p transforms/helloworld.py",
             ]
@@ -169,13 +169,13 @@ def _start(commands):
         },
         {
             "cmd": [
-                "enrichpkg bootstrap -c pipeline-conf -p pipelines/conf/persona.py"
+                "enrichpkg bootstrap -c pipeline-conf -p pipelines/conf/helloworld.py"
             ],
             "description": "Bootstrap a pipeline"
         },
         {
             "cmd": [
-                "enrichpkg test conf --capture pipelines/conf/persona.py"
+                "enrichpkg test conf --capture pipelines/conf/helloworld.py"
             ],
             "description": "Check pipeline"
         },
@@ -520,31 +520,33 @@ def _testdata_show(ctx, dataset):
                             ctx.obj['context'],
                             name=dataset)
 
-@testdata.command('download')
+@testdata.command('run',
+                  context_settings=dict(
+                      ignore_unknown_options=True,
+                      allow_extra_args=True,
+                  ))
 @click.argument('dataset')
 @click.argument('command')
-@click.argument('start')
-@click.argument('end')
-@click.option('--src', required=True)
-@click.option('--dst', required=True)
 @click.pass_context
-def _testdata_download(ctx, dataset, command, src, dst, start, end):
+def _testdata_action(ctx, dataset, command):
     """
-    Download dataset for a specified range
+    Generate action commands for a dataset over a specified range
 
-    For command, src and dst use 'show'
+    Pass additional parameters as key-value pairs as 
+    shown in show.
     """
 
-    package.testdata_action("download",
+    args = dict()
+    for item in ctx.args:
+        args.update([item.split('=')])
+
+    package.testdata_action("action",
                             ctx.obj['spec'],
                             ctx.obj['capture'],
                             ctx.obj['context'],
                             name=dataset,
-                            src=src,
-                            dst=dst,
                             command=command,
-                            start=start,
-                            end=end)
+                            **args)
 
 
 test.add_command(testdata)
